
Numina Documentation
====================

Welcome. This is the Documentation for Numina (version |version|, date |today|), 

Numina user guide: :ref:`user`

Numina pipeline creation guide: :ref:`creation`

Numina reference guide: :ref:`reference`.

.. toctree::
   :maxdepth: 1

   user/index
   creation/index
   reference/index
   glossary

Maintainers: Sergio Pascual sergiopr@fis.ucm.es, Nicolás Cardiel cardiel@ucm.es

.. _GTC: http://www.gtc.iac.es
